@@ -23,6 +23,7 @@
 #define _feed_list_node_H
 
 #include <gtk/gtk.h>
+#include <src/subscription.h>
 #include "node.h"
 
 /**
@@ -110,8 +111,17 @@ void feed_list_node_rename (nodePtr node);
  * function does not block, so the folder/feeds will not have
  * been deleted when this function returns.
  *
- * @param node	the node to remove
+ * @param node		the node to remove
  */
 void feed_list_node_remove (nodePtr node);
 
+/**
+ * Prompt the user for confirmation and forces adding the node,
+ * even though another node with the same URL exists.
+ *
+ * @param tempSubscription	the duplicate URL subscription
+ * @param exNode			the existing node
+ */
+void feed_list_node_add_duplicate_url_subscription (subscriptionPtr tempSubscription, nodePtr exNode);
+
 #endif
